==> haskell-parser-combinators-1.3.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parser-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parser-combinators
version:              1.3.0
visibility:           public
id:                   parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6
key:                  parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Mark Karpov <markkarpov92@gmail.com>
    Alex Washburn <github@recursion.ninja>

homepage:             https://github.com/mrkkrp/parser-combinators
synopsis:
    Lightweight package providing commonly useful parser combinators

description:
    Lightweight package providing commonly useful parser combinators.

category:             Parsing
abi:                  0e2655ed88a5517da9e2df9b36b8cab4
exposed:              True
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.Expr Control.Monad.Combinators.NonEmpty
    Control.Monad.Permutations

import-dirs:          /usr/lib/ghc-9.0.1/site-local/parser-combinators-1.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/parser-combinators-1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/parser-combinators-1.3.0
hs-libraries:         HSparser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock

haddock-html:         /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parser-combinators-1.3.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parser-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parser-combinators
version:              1.3.0
visibility:           public
id:                   parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB
key:                  parser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Mark Karpov <markkarpov92@gmail.com>
    Alex Washburn <github@recursion.ninja>

homepage:             https://github.com/mrkkrp/parser-combinators
synopsis:
    Lightweight package providing commonly useful parser combinators

description:
    Lightweight package providing commonly useful parser combinators.

category:             Parsing
abi:                  dc9cbe83b9add44d452932fe6122cb45
exposed:              True
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.Expr Control.Monad.Combinators.NonEmpty
    Control.Monad.Permutations

import-dirs:          /usr/lib/ghc-9.0.2/site-local/parser-combinators-1.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/parser-combinators-1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/parser-combinators-1.3.0
hs-libraries:         HSparser-combinators-1.3.0-FL5bcA6sX4a2ejs4tDtkjB
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock

haddock-html:         /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
